# Counter client

## Description

This module contains a client for the counter ABCI skill for an AEA.

## Behaviours

* `BaseBehaviour`

   Abstract base behaviour for this skill.

* `IncrementerBehaviour`

   Send a transaction

* `MonitorBehaviour`

   Send an ABCI query periodically.


## Handlers

* `HttpHandler`

   The HTTP response handler.


